==> haskell-x509-system-1.6.3-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-x509-system/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-system
version: 1.6.3
id: x509-system-1.6.3-ab7219111a5707b62bd7446e2bff807d
key: x509s_I4cYAxvPCFhBUyzgmyylPO
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: Handle per-operating-system X.509 accessors and storage
description:
    System X.509 handling
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    System.X509 System.X509.Unix System.X509.MacOS
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/x509-system-1.6.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/x509-system-1.6.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/x509-system-1.6.3
hs-libraries: HSx509-system-1.6.3-I4cYAxvPCFhBUyzgmyylPO
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    pem-0.2.2-5f6df2ca3b7f68abc9010881cb82b5dd
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    x509-1.6.3-88141428fd098325953c29fe36fd878e
    x509-store-1.6.1-43770428c1088301ba6ed013a258fa1c
haddock-interfaces: /usr/share/doc/haskell-x509-system/html/x509-system.haddock
haddock-html: /usr/share/doc/haskell-x509-system/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-system-1.6.3-7-armv7h.pkg.tar.xz: usr/share/haskell/haskell-x509-system/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-system
version: 1.6.3
id: x509-system-1.6.3-6ba9c22edd2365d0a08eb6f448807838
key: x509s_KNkL3i73hVQJleBQzr6DhW
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: Handle per-operating-system X.509 accessors and storage
description:
    System X.509 handling
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    System.X509 System.X509.Unix System.X509.MacOS
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/x509-system-1.6.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/x509-system-1.6.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/x509-system-1.6.3
hs-libraries: HSx509-system-1.6.3-KNkL3i73hVQJleBQzr6DhW
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    pem-0.2.2-5f6df2ca3b7f68abc9010881cb82b5dd
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    x509-1.6.3-9c5cbae50b7250847fc648c7f7d122e6
    x509-store-1.6.1-741461c55f7edc5697c99a37f0436ee6
haddock-interfaces: /usr/share/doc/haskell-x509-system/html/x509-system.haddock
haddock-html: /usr/share/doc/haskell-x509-system/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
